extract_log_lik: Extract log-likelihood matrix from clmstan object

View source: R/loo_waic.R

extract_log_likR Documentation

Extract log-likelihood matrix from clmstan object

Description

Extract log-likelihood matrix from clmstan object

Usage

extract_log_lik(object)

Arguments

object

A clmstan object

Value

An S x N matrix of log-likelihood values, where S is the number of posterior samples and N is the number of observations.


clmstan documentation built on June 29, 2026, 5:06 p.m.