get_model_name: Get Stan model name based on threshold and full model flag

View source: R/links.R

get_model_nameR Documentation

Get Stan model name based on threshold and full model flag

Description

Get Stan model name based on threshold and full model flag

Usage

get_model_name(threshold, full = FALSE)

Arguments

threshold

A character string specifying the threshold structure

full

Logical indicating whether link parameters are estimated

Value

A character string with the Stan model name


clmstan documentation built on June 29, 2026, 5:06 p.m.