| prepare_stan_data_dispatch | R Documentation |
Routes to the correct prepare function based on threshold structure and whether link parameters are being estimated.
prepare_stan_data_dispatch(
formula,
data,
link,
base,
link_param,
threshold,
full,
prior
)
formula |
A formula specifying the model |
data |
A data frame containing the variables |
link |
Link function name |
base |
Base distribution for SP link |
link_param |
A list of link parameters |
threshold |
Threshold structure |
full |
Whether to use full model (estimate link parameters) |
prior |
A clm_prior object or NULL for default priors |
A list suitable for passing to CmdStan
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.