validate_prior_class_dist: Validate that the distribution is compatible with the parameter class
Description
Validate that the distribution is compatible with the parameter class
Usage
validate_prior_class_dist(class, dist)
Arguments
- class
The parameter class
- dist
A clm_dist object