| extract_log_lik | R Documentation |
Extract log-likelihood matrix from clmstan object
extract_log_lik(object)
object |
A clmstan object |
An S x N matrix of log-likelihood values, where S is the number of posterior samples and N is the number of observations.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.