Learn R Programming

clmstan (version 0.1.1)

extract_log_lik: Extract log-likelihood matrix from clmstan object

Description

Extract log-likelihood matrix from clmstan object

Usage

extract_log_lik(object)

Value

An S x N matrix of log-likelihood values, where S is the number of posterior samples and N is the number of observations.

Arguments

object

A clmstan object