powered by
Extract log-likelihood matrix from clmstan object
extract_log_lik(object)
An S x N matrix of log-likelihood values, where S is the number of posterior samples and N is the number of observations.
A clmstan object