Learn R Programming

clmstan (version 0.1.1)

flat: Flat (Improper Uniform) Prior Distribution

Description

Creates a flat (improper uniform) distribution object for use with prior(). A flat prior assigns equal probability density to all values, which is improper (does not integrate to 1) but can be used when the likelihood provides sufficient information for identification.

Usage

flat()

Arguments

Value

An object of class "clm_dist" representing a flat distribution.

See Also

prior(), normal(), student_t(), cauchy()

Examples

Run this code
# Create a flat prior for regression coefficients
prior(flat(), class = "b")

# Flat prior for thresholds (flexible)
prior(flat(), class = "Intercept")

Run the code above in your browser using DataLab