get_model_name: Get Stan model name based on threshold and full model flag
Description
Get Stan model name based on threshold and full model flag
Usage
get_model_name(threshold, full = FALSE)
Value
A character string with the Stan model name
Arguments
- threshold
A character string specifying the threshold structure
- full
Logical indicating whether link parameters are estimated