| posterior_predict.clmstan | R Documentation |
Draws from the posterior predictive distribution. For each posterior sample, a predicted category is sampled from the categorical distribution with the predicted probabilities.
posterior_predict.clmstan(object, newdata = NULL, ndraws = NULL, ...)
object |
A |
newdata |
Optional data frame for prediction. If |
ndraws |
Number of posterior draws to use. If |
... |
Additional arguments (currently ignored). |
An integer matrix of dimension S x N containing predicted categories (1 to K), where S is the number of posterior draws and N is the number of observations.
predict.clmstan(), fitted.clmstan()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.