Draws from the posterior predictive distribution. For each posterior sample, a predicted category is sampled from the categorical distribution with the predicted probabilities.
posterior_predict.clmstan(object, newdata = NULL, ndraws = NULL, ...)An integer matrix of dimension S x N containing predicted categories (1 to K), where S is the number of posterior draws and N is the number of observations.
A clmstan object returned by clm_stan().
Optional data frame for prediction. If NULL (default),
predictions are made for the original training data.
Number of posterior draws to use. If NULL (default),
all available draws are used.
Additional arguments (currently ignored).
predict.clmstan(), fitted.clmstan()